package cn.com.ty.lift.system.faq.controller;


import cn.com.ty.lift.system.faq.entity.Faq;
import cn.com.ty.lift.system.faq.mapper.FaqMapper;
import cn.com.ty.lift.system.faq.service.impl.FaqServiceImpl;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;

import lombok.AllArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;

/**
 * @author wang-hai-cheng
 * @date 2019/11/27
 * @description 常见问题级常见问题分类表 前端控制器
 */
@RestController
@RequestMapping("/faq")
@AllArgsConstructor
public class FaqController {
    private final FaqServiceImpl faqService;
    private final FaqMapper faqMapper;

    @GetMapping("/one")
    /**
     * @description 查询一级分类
     * @date 2019/11/27 10:19
     * @param []
     * @return java.util.List<cn.com.ty.lift.system.faq.entity.Faq>
     */
    public List<Faq> one() {
        return faqService.list(new QueryWrapper<Faq>().eq("type", 1).eq("parent_id", 0).orderByAsc("serial"));
    }

    @GetMapping("/child")
    /**
     * @description 根据父分类id查询子分类
     * @date 2019/11/27 10:19
     * @param [parentId]
     * @return java.util.List<cn.com.ty.lift.system.faq.entity.Faq>
     */
    public List<Faq> child(int parentId) {
        return faqService.list(new QueryWrapper<Faq>().eq("type", 1).eq("parent_id", parentId).orderByAsc("serial"));
    }

    @GetMapping("/question")
    /**
     * @description 根据分类id查询问题标题列表
     * @date 2019/11/27 10:25
     * @param [parentId]
     * @return java.util.List<cn.com.ty.lift.system.faq.entity.Faq>
     */
    public List<Faq> question(int parentId) {
        return faqService.list(new QueryWrapper<Faq>().eq("type", 2).eq("parent_id", parentId).orderByAsc("serial"));
    }

    @GetMapping("/answer")
    /**
     * @description 根据问题id查询答案
     * @date 2019/11/27 10:31
     * @param [parentId]
     * @return cn.com.ty.lift.system.faq.entity.Faq
     */
    public Faq answer(int parentId) {
        return faqService.getOne(new QueryWrapper<Faq>().eq("type", 3).eq("parent_id", parentId).orderByAsc("serial"));
    }

    @PostMapping("/add/one")
    /**
     * @description 新增一级分类
     * @date 2019/11/27 10:47
     * @param [faq]
     * @return org.springframework.http.ResponseEntity
     */
    public ResponseEntity addOne(Faq faq) {
        //@RequestParam String title, @RequestParam String description
        return faqService.addOne(faq.getContent(), faq.getDescription());
    }

    @PostMapping("/add/child")
    /**
     * @description 新增子分类
     * @date 2019/11/27 10:47
     * @param [faq]
     * @return org.springframework.http.ResponseEntity
     */
    public ResponseEntity addChild(Faq faq) {
        //@RequestParam int parentId, @RequestParam String title, @RequestParam String description
        return faqService.addChild(faq.getParentId(), faq.getContent(), faq.getDescription());
    }

    @PostMapping("/add/question")
    /**
         * @description 根据分类id新增问题
         * @date 2019/11/27 10:51
         * @param [faq]
         * @return org.springframework.http.ResponseEntity
         */
    public ResponseEntity addQuestion(Faq faq) {
        //@RequestParam int parentId, @RequestParam String title, @RequestParam String description
        return faqService.addQuestion(faq.getParentId(), faq.getContent(), faq.getDescription());
    }

    @PostMapping("/add/answer")
    /**
         * @description 根据问题id新增答案
         * @date 2019/11/27 10:51
         * @param [faq]
         * @return org.springframework.http.ResponseEntity
         */
    public ResponseEntity addAnswer(Faq faq) {
        //@RequestParam int parentId, @RequestParam String content, @RequestParam String description
        return faqService.addAnswer(faq.getParentId(), faq.getContent(), faq.getDescription());
    }

    @PostMapping("/update")
    /**
         * @description 更新分类名或问题标题或答案内容,都是title参数,description是对此id信息的描述
         * @date 2019/11/27 10:51
         * @param [faq]
         * @return org.springframework.http.ResponseEntity
         */
    public ResponseEntity updateOne(Faq faq) {
        return faqService.up(faq.getId(), faq.getContent(), faq.getDescription());
    }

    @PostMapping("/delete")
    /**
         * @description 根据id删除此id下的分类和问答
         * @date 2019/11/27 10:51
         * @param [id]
         * @return org.springframework.http.ResponseEntity
         */
    public ResponseEntity deleteAll(int id) {
        return faqService.delete(id);
    }

    @GetMapping("/up")
    /** 排序上移一位
         * @description
         * @date 2019/11/27 10:52
         * @param [id]
         * @return org.springframework.http.ResponseEntity
         */
    public ResponseEntity up(int id) {
        return faqService.up(id);
    }

    @GetMapping("/down")
    /**
         * @description 排序下移一位
         * @date 2019/11/27 10:52
         * @param [id]
         * @return org.springframework.http.ResponseEntity
         */
    public ResponseEntity down(int id) {
        return faqService.down(id);
    }
}